pub struct MouseWindowLocation { /* private fields */ }Expand description
Mouse’s location within a window, in points.
The coordinate system has its origin at the upper-left corner of the window. The position is reported in logical points, not physical pixels.
Examples
use app_window::input::mouse::Mouse;
let mouse = Mouse::coalesced().await;
if let Some(location) = mouse.window_pos() {
println!("Mouse at ({}, {})", location.pos_x(), location.pos_y());
println!("Window size: {}x{}", location.window_width(), location.window_height());
}Implementations
Sourceimpl MouseWindowLocation
impl MouseWindowLocation
Sourcepub fn pos_x(&self) -> f64
pub fn pos_x(&self) -> f64
Returns the X coordinate of the mouse position within the window.
The X coordinate is measured from the left edge of the window.
Examples
if let Some(location) = mouse.window_pos() {
let x = location.pos_x();
println!("Mouse X: {}", x);
}Sourcepub fn pos_y(&self) -> f64
pub fn pos_y(&self) -> f64
Returns the Y coordinate of the mouse position within the window.
The Y coordinate is measured from the top edge of the window.
Examples
if let Some(location) = mouse.window_pos() {
let y = location.pos_y();
println!("Mouse Y: {}", y);
}Sourcepub fn window_width(&self) -> f64
pub fn window_width(&self) -> f64
Returns the width of the window containing the mouse.
Examples
if let Some(location) = mouse.window_pos() {
let width = location.window_width();
println!("Window width: {}", width);
}Sourcepub fn window_height(&self) -> f64
pub fn window_height(&self) -> f64
Returns the height of the window containing the mouse.
Examples
if let Some(location) = mouse.window_pos() {
let height = location.window_height();
println!("Window height: {}", height);
}Trait Implementations
Sourceimpl Clone for MouseWindowLocation
impl Clone for MouseWindowLocation
Sourcefn clone(&self) -> MouseWindowLocation
fn clone(&self) -> MouseWindowLocation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MouseWindowLocation